#!/bin/bash
#
# ** header v3.0
# This file is a part of the CaosDB Project.
#
# Copyright (C) 2021 IndiScale GmbH
# Copyright (C) 2021 Timm Fitschen <t.fitschen@indiscale.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <https://www.gnu.org/licenses/>.
#
# ** end header

# This file can be used to merge js files together.
#
# call: `./merge_js.sh [JS_FILE]*`
#     where the JS_FILE are the files which will be merged into the resulting
#     `public/webcaosdb.dist.js` in the order they appear in the command line
#     call. See `Makefile` for an example.
#
# All other files in `public/js` are appended to the resulting file in no
# particular order.


CORE_MODULES=$@
SOURCE_DIR=public/js/
TARGET=public/webcaosdb.dist.js

function _merge () {
    _SOURCE=$2
    _TARGET=$3

    echo "merging $1 module ${_SOURCE} into ${_TARGET}"


    echo "//COPIED FROM ${_SOURCE} (START)" >> ${_TARGET}
    cat ${_SOURCE} >> ${_TARGET}
    echo "//COPIED FROM ${_SOURCE} (END)" >> ${_TARGET}

    rm ${_SOURCE}
}

# clean up old
rm $TARGET || true
touch $TARGET

for _SOURCE in ${CORE_MODULES[@]} ; do
    _merge "core" "${SOURCE_DIR}${_SOURCE}" $TARGET
done

# load other js files but exclude any subdirectory
for _SOURCE in $(find ${SOURCE_DIR}* -prune -iname "*.js") ; do
    _merge "extension" ${_SOURCE} $TARGET
done

# for `make test`
for _SOURCE in $(find ${SOURCE_DIR} -ipath "${SOURCE_DIR}modules/*.js") ; do
    _merge "extension" ${_SOURCE} $TARGET
done

